==> beast-stock-api-1.4.9-sources.jar: com/thebeastshop/stock/vo/SWhCommandVO.java <==
package com.thebeastshop.stock.vo;

import com.thebeastshop.common.BaseDO;
import com.thebeastshop.common.utils.NullUtil;
import com.thebeastshop.stock.dto.SStockReleaseDTO;

import java.util.Date;
import java.util.List;

/**
 * Created by libin.kang on 2018/10/17.
 */
public class SWhCommandVO extends BaseDO {

    private Long id;

    private String code;

    private Integer commandStatus;

    private String warehouseCode;

    private Integer inOutType;

    private String referenceCode;

    private Date createTime;

    private Date processTime;

    private Date planedDeliveryDate;

    private String batchNo;

    private String ext1;

    private String ext2;

    private String ext3;

    private String ext4;

    private String ext5;

    private Integer expressType;

    private String expressNo;

    private Date weightDate;

    private Long weightUserId;

    private Float weight;

    private Integer cancelFlag;

    private Integer failureStartConnect;

    private String physicalWarehouseCode;

    private Integer commodityStatus;

    private List<SWhCommandSkuVO> commandSkuList;
    //占用回滚List
    private List<SOccupyResultVO> rollbackOccupyList;

    private List<SStockRecordVO> stockRecordList;//完成指令时出入库记录

    private List<SStockRecordVO> rollbackStockRecordList;

    private List<SStockReleaseDTO> stockReleaseList;//完成指令时占用释放记录

    private List<SReleaseResultVO> rollbackStockReleasList;







    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Integer getCommandStatus() {
        return commandStatus;
    }

    public void setCommandStatus(Integer commandStatus) {
        this.commandStatus = commandStatus;
    }

    public String getWarehouseCode() {
        return warehouseCode;
    }

    public void setWarehouseCode(String warehouseCode) {
        this.warehouseCode = warehouseCode;
    }

    public Integer getInOutType() {
        return inOutType;
    }

    public void setInOutType(Integer inOutType) {
        this.inOutType = inOutType;
    }

    public String getReferenceCode() {
        return referenceCode;
    }

    public void setReferenceCode(String referenceCode) {
        this.referenceCode = referenceCode;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getProcessTime() {
        return processTime;
    }

    public void setProcessTime(Date processTime) {
        this.processTime = processTime;
    }

    public Date getPlanedDeliveryDate() {
        return planedDeliveryDate;
    }

    public void setPlanedDeliveryDate(Date planedDeliveryDate) {
        this.planedDeliveryDate = planedDeliveryDate;
    }

    public String getBatchNo() {
        return batchNo;
    }

    public void setBatchNo(String batchNo) {
        this.batchNo = batchNo;
    }

    public String getExt1() {
        return ext1;
    }

    public void setExt1(String ext1) {
        this.ext1 = ext1;
    }

    public String getExt2() {
        return ext2;
    }

    public void setExt2(String ext2) {
        this.ext2 = ext2;
    }

    public String getExt3() {
        return ext3;
    }

    public void setExt3(String ext3) {
        this.ext3 = ext3;
    }

    public String getExt4() {
        return ext4;
    }

    public void setExt4(String ext4) {
        this.ext4 = ext4;
    }

    public String getExt5() {
        return ext5;
    }

    public void setExt5(String ext5) {
        this.ext5 = ext5;
    }

    public Integer getExpressType() {
        return expressType;
    }

    public void setExpressType(Integer expressType) {
        this.expressType = expressType;
    }

    public String getExpressNo() {
        return expressNo;
    }

    public void setExpressNo(String expressNo) {
        this.expressNo = expressNo;
    }

    public Date getWeightDate() {
        return weightDate;
    }

    public void setWeightDate(Date weightDate) {
        this.weightDate = weightDate;
    }

    public Long getWeightUserId() {
        return weightUserId;
    }

    public void setWeightUserId(Long weightUserId) {
        this.weightUserId = weightUserId;
    }

    public Float getWeight() {
        return weight;
    }

    public void setWeight(Float weight) {
        this.weight = weight;
    }

    public Integer getCancelFlag() {
        return cancelFlag;
    }

    public void setCancelFlag(Integer cancelFlag) {
        this.cancelFlag = cancelFlag;
    }

    public Integer getFailureStartConnect() {
        return failureStartConnect;
    }

    public void setFailureStartConnect(Integer failureStartConnect) {
        this.failureStartConnect = failureStartConnect;
    }

    public String getPhysicalWarehouseCode() {
        return physicalWarehouseCode;
    }

    public void setPhysicalWarehouseCode(String physicalWarehouseCode) {
        this.physicalWarehouseCode = physicalWarehouseCode;
    }

    @Override
    public String toString() {
        return "SWhCommandVO[id="+this.getId()+",CommandStatus="+this.getCommandStatus()+",processTime="+this.getProcessTime();
    }

    public List<SWhCommandSkuVO> getCommandSkuList() {
        return commandSkuList;
    }

    public void setCommandSkuList(List<SWhCommandSkuVO> commandSkuList) {
        this.commandSkuList = commandSkuList;
    }

    public boolean isIn() {
        return this.inOutType / 10 == 1;
    }

    public boolean isOut() {
        return this.inOutType / 10 == 2 || this.inOutType == 32 || this.inOutType == 33;
    }

    public List<SOccupyResultVO> getRollbackOccupyList() {
        return rollbackOccupyList;
    }

    public void setRollbackOccupyList(List<SOccupyResultVO> rollbackOccupyList) {
        this.rollbackOccupyList = rollbackOccupyList;
    }

    public List<SStockRecordVO> getStockRecordList() {
        return stockRecordList;
    }

    public void setStockRecordList(List<SStockRecordVO> stockRecordList) {
        this.stockRecordList = stockRecordList;
    }

    public List<SStockRecordVO> getRollbackStockRecordList() {
        return rollbackStockRecordList;
    }

    public void setRollbackStockRecordList(List<SStockRecordVO> rollbackStockRecordList) {
        this.rollbackStockRecordList = rollbackStockRecordList;
    }

    public List<SStockReleaseDTO> getStockReleaseList() {
        return stockReleaseList;
    }

    public void setStockReleaseList(List<SStockReleaseDTO> stockReleaseList) {
        this.stockReleaseList = stockReleaseList;
    }

    public List<SReleaseResultVO> getRollbackStockReleasList() {
        return rollbackStockReleasList;
    }

    public void setRollbackStockReleasList(List<SReleaseResultVO> rollbackStockReleasList) {
        this.rollbackStockReleasList = rollbackStockReleasList;
    }

    public Integer getCommodityStatus() {
        return commodityStatus;
    }

    public void setCommodityStatus(Integer commodityStatus) {
        this.commodityStatus = commodityStatus;
    }
}

==> beast-stock-api-1.6.0-20201031.060538-13-sources.jar: com/thebeastshop/stock/vo/SWhCommandVO.java <==
package com.thebeastshop.stock.vo;

import com.thebeastshop.common.BaseDO;
import com.thebeastshop.common.utils.NullUtil;
import com.thebeastshop.stock.dto.SStockReleaseDTO;

import java.util.Date;
import java.util.List;

/**
 * Created by libin.kang on 2018/10/17.
 */
public class SWhCommandVO extends BaseDO {

    private Long id;

    private String code;

    private Integer commandStatus;

    private String warehouseCode;

    private Integer inOutType;

    private String referenceCode;

    private Date createTime;

    private Date processTime;

    private Date planedDeliveryDate;

    private String batchNo;

    private String ext1;

    private String ext2;

    private String ext3;

    private String ext4;

    private String ext5;

    private Integer expressType;

    private String expressNo;

    private Date weightDate;

    private Long weightUserId;

    private Float weight;

    private Integer cancelFlag;

    private Integer failureStartConnect;

    private String physicalWarehouseCode;

    private Integer commodityStatus;

    private Integer specialType;

    private List<SWhCommandSkuVO> commandSkuList;
    //占用回滚List
    private List<SOccupyResultVO> rollbackOccupyList;

    private List<SStockRecordVO> stockRecordList;//完成指令时出入库记录

    private List<SStockRecordVO> rollbackStockRecordList;

    private List<SStockReleaseDTO> stockReleaseList;//完成指令时占用释放记录

    private List<SReleaseResultVO> rollbackStockReleasList;







    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Integer getCommandStatus() {
        return commandStatus;
    }

    public void setCommandStatus(Integer commandStatus) {
        this.commandStatus = commandStatus;
    }

    public String getWarehouseCode() {
        return warehouseCode;
    }

    public void setWarehouseCode(String warehouseCode) {
        this.warehouseCode = warehouseCode;
    }

    public Integer getInOutType() {
        return inOutType;
    }

    public void setInOutType(Integer inOutType) {
        this.inOutType = inOutType;
    }

    public String getReferenceCode() {
        return referenceCode;
    }

    public void setReferenceCode(String referenceCode) {
        this.referenceCode = referenceCode;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getProcessTime() {
        return processTime;
    }

    public void setProcessTime(Date processTime) {
        this.processTime = processTime;
    }

    public Date getPlanedDeliveryDate() {
        return planedDeliveryDate;
    }

    public void setPlanedDeliveryDate(Date planedDeliveryDate) {
        this.planedDeliveryDate = planedDeliveryDate;
    }

    public String getBatchNo() {
        return batchNo;
    }

    public void setBatchNo(String batchNo) {
        this.batchNo = batchNo;
    }

    public String getExt1() {
        return ext1;
    }

    public void setExt1(String ext1) {
        this.ext1 = ext1;
    }

    public String getExt2() {
        return ext2;
    }

    public void setExt2(String ext2) {
        this.ext2 = ext2;
    }

    public String getExt3() {
        return ext3;
    }

    public void setExt3(String ext3) {
        this.ext3 = ext3;
    }

    public String getExt4() {
        return ext4;
    }

    public void setExt4(String ext4) {
        this.ext4 = ext4;
    }

    public String getExt5() {
        return ext5;
    }

    public void setExt5(String ext5) {
        this.ext5 = ext5;
    }

    public Integer getExpressType() {
        return expressType;
    }

    public void setExpressType(Integer expressType) {
        this.expressType = expressType;
    }

    public String getExpressNo() {
        return expressNo;
    }

    public void setExpressNo(String expressNo) {
        this.expressNo = expressNo;
    }

    public Date getWeightDate() {
        return weightDate;
    }

    public void setWeightDate(Date weightDate) {
        this.weightDate = weightDate;
    }

    public Long getWeightUserId() {
        return weightUserId;
    }

    public void setWeightUserId(Long weightUserId) {
        this.weightUserId = weightUserId;
    }

    public Float getWeight() {
        return weight;
    }

    public void setWeight(Float weight) {
        this.weight = weight;
    }

    public Integer getCancelFlag() {
        return cancelFlag;
    }

    public void setCancelFlag(Integer cancelFlag) {
        this.cancelFlag = cancelFlag;
    }

    public Integer getFailureStartConnect() {
        return failureStartConnect;
    }

    public void setFailureStartConnect(Integer failureStartConnect) {
        this.failureStartConnect = failureStartConnect;
    }

    public Integer getSpecialType() {
        return specialType;
    }

    public void setSpecialType(Integer specialType) {
        this.specialType = specialType;
    }

    public String getPhysicalWarehouseCode() {
        return physicalWarehouseCode;
    }

    public void setPhysicalWarehouseCode(String physicalWarehouseCode) {
        this.physicalWarehouseCode = physicalWarehouseCode;
    }

    @Override
    public String toString() {
        return "SWhCommandVO[id="+this.getId()+",CommandStatus="+this.getCommandStatus()+",processTime="+this.getProcessTime();
    }

    public List<SWhCommandSkuVO> getCommandSkuList() {
        return commandSkuList;
    }

    public void setCommandSkuList(List<SWhCommandSkuVO> commandSkuList) {
        this.commandSkuList = commandSkuList;
    }

    public boolean isIn() {
        return this.inOutType / 10 == 1;
    }

    public boolean isOut() {
        return this.inOutType / 10 == 2 || this.inOutType == 32 || this.inOutType == 33;
    }

    public List<SOccupyResultVO> getRollbackOccupyList() {
        return rollbackOccupyList;
    }

    public void setRollbackOccupyList(List<SOccupyResultVO> rollbackOccupyList) {
        this.rollbackOccupyList = rollbackOccupyList;
    }

    public List<SStockRecordVO> getStockRecordList() {
        return stockRecordList;
    }

    public void setStockRecordList(List<SStockRecordVO> stockRecordList) {
        this.stockRecordList = stockRecordList;
    }

    public List<SStockRecordVO> getRollbackStockRecordList() {
        return rollbackStockRecordList;
    }

    public void setRollbackStockRecordList(List<SStockRecordVO> rollbackStockRecordList) {
        this.rollbackStockRecordList = rollbackStockRecordList;
    }

    public List<SStockReleaseDTO> getStockReleaseList() {
        return stockReleaseList;
    }

    public void setStockReleaseList(List<SStockReleaseDTO> stockReleaseList) {
        this.stockReleaseList = stockReleaseList;
    }

    public List<SReleaseResultVO> getRollbackStockReleasList() {
        return rollbackStockReleasList;
    }

    public void setRollbackStockReleasList(List<SReleaseResultVO> rollbackStockReleasList) {
        this.rollbackStockReleasList = rollbackStockReleasList;
    }

    public Integer getCommodityStatus() {
        return commodityStatus;
    }

    public void setCommodityStatus(Integer commodityStatus) {
        this.commodityStatus = commodityStatus;
    }
}
